(self["webpackChunk_molinsp_eigendata"] = self["webpackChunk_molinsp_eigendata"] || []).push([["style_index_js"],{

/***/ "./node_modules/css-loader/dist/cjs.js!./style/base.css":
/*!**************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js!./style/base.css ***!
  \**************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../node_modules/css-loader/dist/runtime/cssWithMappingToString.js */ "./node_modules/css-loader/dist/runtime/cssWithMappingToString.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../node_modules/css-loader/dist/runtime/api.js */ "./node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../node_modules/css-loader/dist/runtime/getUrl.js */ "./node_modules/css-loader/dist/runtime/getUrl.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _logo_png__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./logo.png */ "./style/logo.png");
// Imports




var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default()));
var ___CSS_LOADER_URL_REPLACEMENT_0___ = _node_modules_css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(_logo_png__WEBPACK_IMPORTED_MODULE_3__.default);
// Module
___CSS_LOADER_EXPORT___.push([module.id, "/* |----------------------- COMMON STYLE RULES --------------------------------------------------------------------> */\n\n.jp-ReactWidget {\n  color: var(--jp-ui-font-color1);\n  background: var(--jp-layout-color1);\n  align-items: center;\n  padding-top: 20px;\n  padding-bottom: 10px;\n  padding-right: 20px;\n  padding-left: 20px;\n  overflow: auto;\n  min-height: 400px;\n}\n\n.jp-dataviz{\n  margin-top: -8px;\n  min-width: 650px !important;\n}\n\n.marginsNotebook {\n  padding-right: 5px;\n  padding-left: 70px;\n}\n\n/* Any element that fills its parent by width */\n.full-width {\n  width: 100%;\n}\n\n/* Any element that fills its parent by height */\n.full-height-container {\n  height: 100%;\n}\n\n/* Any element that needs margin */\n.margin-right {\n  margin-right: 10px;\n}\n\n/* Any short element */\n.short {\n  height: 26px !important;\n  padding: 0 12px !important;\n}\n\n/* Any centered element */\n.centered {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n}\n\n/* Make element visible and flexible */\n.show_flex {\n  display: flex !important;\n}\n\n/* Add ellipsis */\n.ellipsized {\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  overflow: hidden;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |----------------------- FORMULABAR: GENERAL STYLING -----------------------------------------------------------> */\n\n.formulaFormDivider{\n  border-bottom: 1px solid black;\n  width: 100%;\n  border-color: #B2B2B2;\n  margin-bottom: 10px;\n}\n\n#root__title{\n  border-bottom-width: 0px;\n  margin-bottom: 5px;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |----------------------- FORMULABAR: SIDE-BY-SIDE FIELDS RULES -------------------------------------------------> */\n\n/* Side-by-side container */\n.side-by-side-fields > fieldset {\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: space-between;\n  width: 100%;\n  margin-bottom: 10px;\n  position: relative;\n}\n\n/* Left and right fields of side-by-side container */\n.side-by-side-fields .left-field,\n.side-by-side-fields .right-field {\n  width: 49%;\n}\n\n/* Rewrite left field rules for data-transformation-form */\n.data-transformation-form .left-field {\n  width: 33%;\n}\n\n/* Rewrite right field rules for data-transformation-form */\n.data-transformation-form .right-field {\n  width: 66%;\n}\n\n/* Rules for description inside of side-by-side container */\n.side-by-side-fields .field-description {\n  width: 100%;\n  margin-bottom: 10px;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n\n/* |----------------------- FORMULABAR: REWRITE ITEMS AT ARRAY LEVEL OF TRANSFORMATIONS.JSON ----------------------> */\n\n/* Item container */\n.array-item {\n  display: flex;\n  align-items: center;\n}\n\n/* Item buttons */\n.array-item-toolbox {\n  margin-bottom: 9px;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n\n/* |----------------------- REWRITE QUERY BUILDER STYLE RULES -----------------------------------------------------> */\n\n#query-form .group-or-rule-container {\n  padding-right: 0;\n}\n\n#query-form .query-builder {\n  margin: 0;\n}\n\n#query-form .query-builder-container {\n  padding: 10px 0;\n  margin-bottom: 20px;\n}\n\n.query-builder-container button {\n  color: #fff;\n  background-color: #337ab7;\n  border-color: #337ab7;\n  display: inline-block;\n  cursor: pointer;\n  padding: 2px 9px;\n  font-size: 14px;\n  line-height: 1.42857143;\n  border-radius: 4px;\n}\n\n/* Make action buttons always visible */\n.group--actions.group--actions--tr {\n  opacity: 1 !important;\n}\n\n/* Style for action buttons */\n.group--actions.group--actions--tr > button {\n  margin-right: 5px;\n}\n\n.group--actions.group--actions--tr > button:last-child {\n  margin-right: 0;\n}\n\n.rule--header > button,\n.group--actions.group--actions--tr > button:nth-child(3) {\n  background: #dc2222;\n  border-color: #dc2222;\n}\n\n/* Styles for rule fields */\n.rule--field,\n.rule--value,\n.rule--operator {\n  width: 30%;\n}\n.rule--operator {\n  max-width: 130px;\n}\n\n.rule--body {\n  display: flex;\n}\n\n.rule--value input {\n  height: 100%;\n  padding: 6px 12px;\n  font-size: 14px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  width: 100%;\n}\n\n/* -------------> Rewrite existing rules for widgets */\n.rule--widget--MULTISELECT,\n.rule--widget--MULTISELECT .widget--widget {\n  width: 100%;\n}\n.rule--widget--NUMBER,\n.rule--widget--NUMBER .widget--widget,\n.rule--widget--TEXT,\n.rule--widget--TEXT .widget--widget{\n  height: 100%;\n  width: 100%;\n}\n/* Set specific width for external block */\n.rule--widget--BOOLEAN {\n  max-width: 70%;\n  width: 170px;\n  height: 100%;\n}\n\n/* Make inner block flex to align elements inside of it */\n.rule--widget--BOOLEAN .widget--widget {\n  display: flex;\n  align-items: center;\n  height: 100%;\n}\n\n/* Remove unnecessary margin from radio button */\n.rule--widget--BOOLEAN .widget--widget input[type=\"radio\"] {\n  margin: 0 10px !important;\n  height: 20px;\n  width: 20px;\n}\n/* <------------------------------------------------- */\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n\n/* |----------------------- DATA VISUALIZER RULES -----------------------------------------------------------------> */\n\n/* |----------- Binder button --------------------------------------->*/\n\n.binderButtonSeparator{\n  margin-bottom: 10px;\n}\n\n.binderButton{\n  background-color: #000000;\n  color: #FFFFFF;\n  border-radius: 1rem;\n  border: 0;\n  padding-top: 5px;\n  padding-bottom: 5px;\n  padding-left: 15px;\n  padding-right: 15px;\n  height: 22px;\n}\n\n.binderButton:hover{\n  color: #FFFFFF;\n  background-color: #5249BA !important;\n  text-decoration: none;\n}\n\n/* <--------------------------------------------------------------|*/\n\n/* |----------- Navigation --------------------------------------->*/\n/* Navigation bar */\n.scroll-nav {\n  overflow-x: auto;\n  overflow-y: hidden;\n  white-space: nowrap;\n  position: relative;\n  z-index: 5;\n}\n\n/* Navigation tab (button) */\n.tab-button {\n  min-width: 77px;\n  height: 30px;\n  background: #FFFFFF;\n  border: 1px solid #DDDDDD;\n  border-right: 0;\n  box-sizing: border-box;\n  border-radius: 4px 0 0 0;\n  font-size: 14px;\n  line-height: 21px;\n  display: inline-block;\n  transition: 0.2s ease;\n}\n\n/* Navigation tab (button) style by hover */\n.tab-button:hover,\n.dropdown-button:hover\n{\n  background-color: #EEEEEE;\n}\n\n/* Navigation tab (button) style if active */\n.tab-button_active {\n  background-color: #ffffff;\n  color: #353EFF !important;\n}\n\n/* Navigation tab (button) style if inactive */\n.tab-button_inactive {\n  color: #959494;\n  background-color: #f6f6f6;\n}\n\n/* Containers for dropdown button */\n.dropdown-container {\n  display: flex;\n}\n\n.dropdown {\n  display: flex;\n  min-width: 97px;\n}\n\n/* Dropdown button container */\n.dropdown-button {\n  height: 30px;\n  padding: 2px 4px;\n  margin-right: 3px;\n  border: 1px solid #DDDDDD;\n  border-left: 0;\n  border-radius: 0 4px 0 0;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n/* Rewrite bootstrap's dropdown menu */\n.dropdown-menu {\n  padding: 0 !important;\n  margin: 0 !important;\n  border-top-left-radius: 0 !important;\n  border-top-right-radius: 0 !important;\n}\n\n/* Rewrite bootstrap's dropdown menu item */\n.dropdown-item {\n  display: block;\n  padding: 2px 10px;\n  color: #212529;\n  width: max-content;\n  text-decoration: none;\n}\n\n.dropdown-item:hover {\n  background-color: #f3f3f3;\n  text-decoration: none;\n  color: #212529;\n}\n\n/* CSS arrow for dropdown container */\n.dropdown-arrow {\n  height: 0;\n  width: 0;\n  border-top: .3em solid;\n  border-right: .3em solid transparent;\n  border-bottom: 0;\n  border-left: .3em solid transparent;\n}\n\n/* Rules for variables button */\n.variables-button {\n  margin-right: 4px;\n  border: 1px solid #CDDCA8;\n  border-top-right-radius: 4px;\n  background-color: #f6f6f6;\n  color: #959494;\n}\n\n.variables-button:hover {\n  background-color: #EEEEEE;\n}\n/* <--------------------------------------------------------------|*/\n\n/* Container for table */\n.tab-item {\n  width: fit-content;\n  max-width: 100%;\n  margin-bottom: 15px;\n  overflow: auto;\n  border: 1px solid #ddd;\n  height: 83%;\n}\n\n.disclaimer {\n  font-size: 12px;\n  color: #2d2d2d;\n  padding: 8px;\n  margin: 0\n}\n\n/* ---> Table rules ------------------------------------------- */\n\n/* Table style */\n.div-table {\n  width: 100%;\n  border-collapse: collapse;\n  display: table;\n  border-color: grey;\n  border-spacing: 2px;\n}\n\n/* Dark header style */\n.thead-dark {\n  background-color: #212529;\n  color: #ffffff;\n}\n\n/* Add padding to all .th children*/\n.th > *{\n  padding: .35rem;\n}\n\n.header {\n  position: relative;\n}\n\n.header:hover > .dropdown-header-button {\n  right: 0;\n}\n\n/* Dropdown button for column headers*/\n.dropdown-header-button {\n  border: 1px solid #949494;\n  transition: right 0.3s ease;\n  position: absolute;\n  width: 34px;\n  max-width: 100%;\n  right: -34px;\n  top: 0;\n  height: 90%;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  border-radius: 4px 0 0 4px;\n  background-color: #969696;\n}\n\n.dropdown-header-button:hover {\n  cursor: pointer;\n}\n\n/* Header for dropdown menu */\n.sort-header {\n  color: #888888;\n  padding: 0 0 0 10px;\n  margin: 0;\n}\n\n/* Dropdown menu for column headers */\n.dropdown-header-menu {\n  padding: 10px;\n  border-radius: 5px;\n  position: absolute;\n  left: 0;\n  top: 50%;\n  z-index: 5;\n  background-color: #e3e3e3;\n  display: none;\n}\n\n/* Position of sort arrow */\n.sort-arrow {\n  position: absolute;\n  right: 10%;\n  top: 0;\n  color: white;\n  display: none;\n}\n\n/* Add different style to index column */\n.index-column-header {\n  background-color: #585757;\n}\n\n/* Style for data type info */\n.data-type-info {\n  color: grey;\n  width: 100%;\n  font-size: 11px;\n  z-index: 1;\n  position: relative;\n}\n\n/* Cell's style */\n.td{\n  padding: .75rem;\n  font-size: 12px;\n}\n\n/* Striped table style */\n.div-table-striped .tbody .tr:nth-of-type(odd) {\n  background-color: rgba(0,0,0,.05);\n}\n\n/* Sticky position for header */\n.sticky {\n  position: sticky;\n  top: 0;\n}\n\n.th, .td {\n  cursor: text;\n}\n\n.tr {\n  width: 100% !important;\n  border-top: 1px solid #dee2e6;\n  align-items: center;\n}\n\n.trash-bin-button {\n  border: none;\n  background-color: transparent;\n}\n\n/* White row for data types background */\n.header-white-row {\n  background-color: white;\n  width: 100%;\n  height: 25px;\n  display: flex;\n  position: absolute;\n  bottom: 0;\n  left: 0;\n  align-items: center;\n  z-index: 1;\n  border-bottom: 1px solid grey;\n}\n\n.delimiter-wrapper {\n  background-color: transparent;\n  width: 8px;\n  position: absolute;\n  top: 0;\n  right: -3px;\n  padding: 0;\n  height: 100%;\n  z-index: 5;\n}\n\n.delimiter {\n  width: 1px;\n  height: 100%;\n  background-color: rgba(128, 128, 128, 0.2);\n  position: absolute;\n  right: 20%;\n}\n\n.delimiter:hover {\n  cursor: col-resize;\n}\n\n/* <------------------------- */\n\n/* <----------------------------------------------------------- */\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |---------------------------------------- PAGINATION PANEL -----------------------------------------------------> */\n\n.pagination-panel {\n  display: flex;\n  border-radius: 3px;\n  flex-wrap: wrap;\n  font-size: 12px;\n}\n\n.pagination-segment {\n  padding: 5px 12px;\n  border: 1px solid hsl(0, 0%, 80%);\n  min-width: 50px;\n  border-radius: 0;\n  transition: all 0.3s ease;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.pagination-page-select {\n  width: 160px;\n}\n\n.pagination-size-select {\n  width: 130px;\n}\n\n.pagination-segment:first-child {\n  border-radius: 3px 0 0 3px;\n}\n\n.pagination-segment:last-child {\n  border-radius: 0 3px 3px 0;\n}\n\nbutton.pagination-segment {\n  background-color: white;\n  color: black;\n}\n\nbutton.pagination-segment:disabled {\n  background-color: #dedede;\n  color: #797979;\n}\n\nbutton.pagination-segment:active {\n  background-color: silver;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |-------------------------------- FEEDBACK BUTTONS STYLE RULES -------------------------------------------------> */\n\n.BinaryFeedback__container,\n.BinaryFeedback__actions {\n  width: 100%;\n}\n\n.BinaryFeedback__positive,\n.BinaryFeedback__negative {\n  width: 50%;\n  border-color: #cccccc !important;\n  justify-content: flex-start !important;\n  padding: 2px 10px !important;\n  min-height: 26px;\n}\n\n.BinaryFeedback__positive {\n  border-radius: 5px 0 0 5px !important;\n}\n.BinaryFeedback__negative {\n  border-radius: 0 5px 5px 0 !important;\n}\n\n.BinaryFeedback__negative:hover p,\n.BinaryFeedback__positive:hover p,\n.BinaryFeedback__selected p,\n.BinaryFeedback__disabled p{\n  color: white !important;\n}\n\n#feedback {\n  display: flex;\n  flex-wrap: wrap;\n  width: 100%;\n  justify-content: space-between;\n}\n\n#feedback__negative-description {\n  display: none;\n  width: 66%;\n  min-width: 310px;\n}\n\n#feedback__buttons {\n  width: 33%;\n  min-width: 230px;\n}\n\n.feedback__content {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  overflow: hidden;\n  width: 100%;\n}\n\n.feedback__buttons-text {\n  margin: 0 0 0 5px;\n  white-space: nowrap;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |--------------------------------- STYLES FOR SVG ICONS --------------------------------------------------------> */\n.svg-magnifier {\n  width: 100%;\n  height: 100%;\n}\n\n.svg-magnifier path,\n.svg-magnifier polygon,\n.svg-magnifier rect {\n  fill: #4691f6;\n}\n\n.svg-magnifier circle {\n  stroke: #4691f6;\n  stroke-width: 1;\n}\n\n.svg-bin path,\n.svg-bin polygon,\n.svg-bin rect {\n  fill: red;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- CHAT WIDGET STYLE -------------------------------------------------------------> */\n\n/* Rewrite native style */\n.Papercups-toggleButtonContainer,\n.Papercups-chatWindowContainer {\n  position: absolute !important;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |------------------------------- RADIO BUTTON GROUP STYLE ------------------------------------------------------> */\n\n/* Container for radio buttons */\n.radio-button-group {\n  position: relative;\n  width: 100%;\n  display: inline-flex;\n  vertical-align: middle;\n}\n\n.radio-wrapper {\n  min-width: 65px;\n}\n\n/* Hide default radio button */\n.radio-button {\n  position: absolute;\n  clip: rect(0,0,0,0);\n  pointer-events: none;\n}\n\n/* Label is the wrapper of radio */\n.radio-button-label {\n  color: #0d6efd;\n  border: 1px solid #0d6efd;\n  padding: 6px 12px;\n  cursor: pointer;\n  transition: all 0.7s ease;\n  width: 100%;\n}\n\n/* Set special borders for first and last buttons */\n.radio-button-group > div:first-child > .radio-button-label {\n  border-top-left-radius: 5px;\n  border-bottom-left-radius: 5px;\n}\n\n.radio-button-group > div:last-child .radio-button-label {\n  border-top-right-radius: 5px;\n  border-bottom-right-radius: 5px;\n}\n\n/* Change colors radio is checked */\n.radio-button:checked+.radio-button-label {\n  color: #fff;\n  background-color: #0d6efd;\n  border-color: #0d6efd;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- EMPTY STATE COMPONENT STYLE ---------------------------------------------------> */\n.empty-state__container {\n  height: 100%;\n  width: 100%;\n  display: flex;\n  flex-flow: column;\n  justify-content: center;\n  align-items: center;\n}\n\n.empty-state__title {\n  font-style: normal;\n  font-weight: bold;\n  font-size: 34px;\n  color: #858585;\n}\n\n.empty-state__link {\n  font-style: normal;\n  font-weight: bold;\n  font-size: 14px;\n  color: #109CF1;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- RELOAD BUTTON STYLE -----------------------------------------------------------> */\n.reload-button__container {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n}\n\n.reload-button__container:active *{\n  color: #a4d1f8;\n}\n\n.reload-button__container > button {\n  border: none;\n  background-color: transparent;\n}\n\n.reload-button__container > label{\n  font-style: normal;\n  font-weight: bold;\n  font-size: 12px;\n  color: #109CF1;\n  cursor: pointer;\n}\n\n.reload-button__container:hover > * {\n  color: #23527c;\n  text-decoration: underline;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------------- SPINNER STYLE -----------------------------------------------------------> */\n.spinner-wrapper {\n  position: fixed;\n  top: 28px;\n  left: 0;\n  width: 100%;\n}\n\n.spinner-wrapper > * {\n  position: inherit !important;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- RESTYLING OF APP -----------------------------------------------------------> */\n\n/* Lines on the top of the widget window removed for more stylized look*/\n:not(.jp-NotebookPanel) > .jp-Toolbar {\n  border-bottom: none;\n  box-shadow: none;\n}\n\n/* Top left logo */\n#jp-MainLogo {\n  margin-left: 3px;\n  width: 26px;\n  background-image: url(" + ___CSS_LOADER_URL_REPLACEMENT_0___ + ")\n}\n\n#jp-MainLogo > svg {\n    visibility: hidden;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- CELL FORMULABAR -----------------------------------------------------------> */\n\n\n.jp-InputArea-editor{\n  background: #F7F7F7;\n  border: none;\n}\n", "",{"version":3,"sources":["webpack://./style/base.css"],"names":[],"mappings":"AAAA,sHAAsH;;AAEtH;EACE,+BAA+B;EAC/B,mCAAmC;EACnC,mBAAmB;EACnB,iBAAiB;EACjB,oBAAoB;EACpB,mBAAmB;EACnB,kBAAkB;EAClB,cAAc;EACd,iBAAiB;AACnB;;AAEA;EACE,gBAAgB;EAChB,2BAA2B;AAC7B;;AAEA;EACE,kBAAkB;EAClB,kBAAkB;AACpB;;AAEA,+CAA+C;AAC/C;EACE,WAAW;AACb;;AAEA,gDAAgD;AAChD;EACE,YAAY;AACd;;AAEA,kCAAkC;AAClC;EACE,kBAAkB;AACpB;;AAEA,sBAAsB;AACtB;EACE,uBAAuB;EACvB,0BAA0B;AAC5B;;AAEA,yBAAyB;AACzB;EACE,aAAa;EACb,uBAAuB;EACvB,mBAAmB;AACrB;;AAEA,sCAAsC;AACtC;EACE,wBAAwB;AAC1B;;AAEA,iBAAiB;AACjB;EACE,uBAAuB;EACvB,mBAAmB;EACnB,gBAAgB;AAClB;;AAEA,sHAAsH;;AAEtH,sHAAsH;;AAEtH;EACE,8BAA8B;EAC9B,WAAW;EACX,qBAAqB;EACrB,mBAAmB;AACrB;;AAEA;EACE,wBAAwB;EACxB,kBAAkB;AACpB;;AAEA,sHAAsH;;AAEtH,sHAAsH;;AAEtH,2BAA2B;AAC3B;EACE,aAAa;EACb,eAAe;EACf,8BAA8B;EAC9B,WAAW;EACX,mBAAmB;EACnB,kBAAkB;AACpB;;AAEA,oDAAoD;AACpD;;EAEE,UAAU;AACZ;;AAEA,0DAA0D;AAC1D;EACE,UAAU;AACZ;;AAEA,2DAA2D;AAC3D;EACE,UAAU;AACZ;;AAEA,2DAA2D;AAC3D;EACE,WAAW;EACX,mBAAmB;AACrB;AACA,sHAAsH;;;AAGtH,sHAAsH;;AAEtH,mBAAmB;AACnB;EACE,aAAa;EACb,mBAAmB;AACrB;;AAEA,iBAAiB;AACjB;EACE,kBAAkB;AACpB;AACA,sHAAsH;;;AAGtH,sHAAsH;;AAEtH;EACE,gBAAgB;AAClB;;AAEA;EACE,SAAS;AACX;;AAEA;EACE,eAAe;EACf,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,yBAAyB;EACzB,qBAAqB;EACrB,qBAAqB;EACrB,eAAe;EACf,gBAAgB;EAChB,eAAe;EACf,uBAAuB;EACvB,kBAAkB;AACpB;;AAEA,uCAAuC;AACvC;EACE,qBAAqB;AACvB;;AAEA,6BAA6B;AAC7B;EACE,iBAAiB;AACnB;;AAEA;EACE,eAAe;AACjB;;AAEA;;EAEE,mBAAmB;EACnB,qBAAqB;AACvB;;AAEA,2BAA2B;AAC3B;;;EAGE,UAAU;AACZ;AACA;EACE,gBAAgB;AAClB;;AAEA;EACE,aAAa;AACf;;AAEA;EACE,YAAY;EACZ,iBAAiB;EACjB,eAAe;EACf,sBAAsB;EACtB,kBAAkB;EAClB,WAAW;AACb;;AAEA,sDAAsD;AACtD;;EAEE,WAAW;AACb;AACA;;;;EAIE,YAAY;EACZ,WAAW;AACb;AACA,0CAA0C;AAC1C;EACE,cAAc;EACd,YAAY;EACZ,YAAY;AACd;;AAEA,yDAAyD;AACzD;EACE,aAAa;EACb,mBAAmB;EACnB,YAAY;AACd;;AAEA,gDAAgD;AAChD;EACE,yBAAyB;EACzB,YAAY;EACZ,WAAW;AACb;AACA,uDAAuD;AACvD,sHAAsH;;;AAGtH,sHAAsH;;AAEtH,uEAAuE;;AAEvE;EACE,mBAAmB;AACrB;;AAEA;EACE,yBAAyB;EACzB,cAAc;EACd,mBAAmB;EACnB,SAAS;EACT,gBAAgB;EAChB,mBAAmB;EACnB,kBAAkB;EAClB,mBAAmB;EACnB,YAAY;AACd;;AAEA;EACE,cAAc;EACd,oCAAoC;EACpC,qBAAqB;AACvB;;AAEA,oEAAoE;;AAEpE,oEAAoE;AACpE,mBAAmB;AACnB;EACE,gBAAgB;EAChB,kBAAkB;EAClB,mBAAmB;EACnB,kBAAkB;EAClB,UAAU;AACZ;;AAEA,4BAA4B;AAC5B;EACE,eAAe;EACf,YAAY;EACZ,mBAAmB;EACnB,yBAAyB;EACzB,eAAe;EACf,sBAAsB;EACtB,wBAAwB;EACxB,eAAe;EACf,iBAAiB;EACjB,qBAAqB;EACrB,qBAAqB;AACvB;;AAEA,2CAA2C;AAC3C;;;EAGE,yBAAyB;AAC3B;;AAEA,4CAA4C;AAC5C;EACE,yBAAyB;EACzB,yBAAyB;AAC3B;;AAEA,8CAA8C;AAC9C;EACE,cAAc;EACd,yBAAyB;AAC3B;;AAEA,mCAAmC;AACnC;EACE,aAAa;AACf;;AAEA;EACE,aAAa;EACb,eAAe;AACjB;;AAEA,8BAA8B;AAC9B;EACE,YAAY;EACZ,gBAAgB;EAChB,iBAAiB;EACjB,yBAAyB;EACzB,cAAc;EACd,wBAAwB;EACxB,aAAa;EACb,mBAAmB;EACnB,uBAAuB;AACzB;;AAEA,sCAAsC;AACtC;EACE,qBAAqB;EACrB,oBAAoB;EACpB,oCAAoC;EACpC,qCAAqC;AACvC;;AAEA,2CAA2C;AAC3C;EACE,cAAc;EACd,iBAAiB;EACjB,cAAc;EACd,kBAAkB;EAClB,qBAAqB;AACvB;;AAEA;EACE,yBAAyB;EACzB,qBAAqB;EACrB,cAAc;AAChB;;AAEA,qCAAqC;AACrC;EACE,SAAS;EACT,QAAQ;EACR,sBAAsB;EACtB,oCAAoC;EACpC,gBAAgB;EAChB,mCAAmC;AACrC;;AAEA,+BAA+B;AAC/B;EACE,iBAAiB;EACjB,yBAAyB;EACzB,4BAA4B;EAC5B,yBAAyB;EACzB,cAAc;AAChB;;AAEA;EACE,yBAAyB;AAC3B;AACA,oEAAoE;;AAEpE,wBAAwB;AACxB;EACE,kBAAkB;EAClB,eAAe;EACf,mBAAmB;EACnB,cAAc;EACd,sBAAsB;EACtB,WAAW;AACb;;AAEA;EACE,eAAe;EACf,cAAc;EACd,YAAY;EACZ;AACF;;AAEA,iEAAiE;;AAEjE,gBAAgB;AAChB;EACE,WAAW;EACX,yBAAyB;EACzB,cAAc;EACd,kBAAkB;EAClB,mBAAmB;AACrB;;AAEA,sBAAsB;AACtB;EACE,yBAAyB;EACzB,cAAc;AAChB;;AAEA,mCAAmC;AACnC;EACE,eAAe;AACjB;;AAEA;EACE,kBAAkB;AACpB;;AAEA;EACE,QAAQ;AACV;;AAEA,sCAAsC;AACtC;EACE,yBAAyB;EACzB,2BAA2B;EAC3B,kBAAkB;EAClB,WAAW;EACX,eAAe;EACf,YAAY;EACZ,MAAM;EACN,WAAW;EACX,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,0BAA0B;EAC1B,yBAAyB;AAC3B;;AAEA;EACE,eAAe;AACjB;;AAEA,6BAA6B;AAC7B;EACE,cAAc;EACd,mBAAmB;EACnB,SAAS;AACX;;AAEA,qCAAqC;AACrC;EACE,aAAa;EACb,kBAAkB;EAClB,kBAAkB;EAClB,OAAO;EACP,QAAQ;EACR,UAAU;EACV,yBAAyB;EACzB,aAAa;AACf;;AAEA,2BAA2B;AAC3B;EACE,kBAAkB;EAClB,UAAU;EACV,MAAM;EACN,YAAY;EACZ,aAAa;AACf;;AAEA,wCAAwC;AACxC;EACE,yBAAyB;AAC3B;;AAEA,6BAA6B;AAC7B;EACE,WAAW;EACX,WAAW;EACX,eAAe;EACf,UAAU;EACV,kBAAkB;AACpB;;AAEA,iBAAiB;AACjB;EACE,eAAe;EACf,eAAe;AACjB;;AAEA,wBAAwB;AACxB;EACE,iCAAiC;AACnC;;AAEA,+BAA+B;AAC/B;EACE,gBAAgB;EAChB,MAAM;AACR;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,sBAAsB;EACtB,6BAA6B;EAC7B,mBAAmB;AACrB;;AAEA;EACE,YAAY;EACZ,6BAA6B;AAC/B;;AAEA,wCAAwC;AACxC;EACE,uBAAuB;EACvB,WAAW;EACX,YAAY;EACZ,aAAa;EACb,kBAAkB;EAClB,SAAS;EACT,OAAO;EACP,mBAAmB;EACnB,UAAU;EACV,6BAA6B;AAC/B;;AAEA;EACE,6BAA6B;EAC7B,UAAU;EACV,kBAAkB;EAClB,MAAM;EACN,WAAW;EACX,UAAU;EACV,YAAY;EACZ,UAAU;AACZ;;AAEA;EACE,UAAU;EACV,YAAY;EACZ,0CAA0C;EAC1C,kBAAkB;EAClB,UAAU;AACZ;;AAEA;EACE,kBAAkB;AACpB;;AAEA,+BAA+B;;AAE/B,iEAAiE;;AAEjE,sHAAsH;;AAEtH,sHAAsH;;AAEtH;EACE,aAAa;EACb,kBAAkB;EAClB,eAAe;EACf,eAAe;AACjB;;AAEA;EACE,iBAAiB;EACjB,iCAAiC;EACjC,eAAe;EACf,gBAAgB;EAChB,yBAAyB;EACzB,aAAa;EACb,mBAAmB;EACnB,uBAAuB;AACzB;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,0BAA0B;AAC5B;;AAEA;EACE,0BAA0B;AAC5B;;AAEA;EACE,uBAAuB;EACvB,YAAY;AACd;;AAEA;EACE,yBAAyB;EACzB,cAAc;AAChB;;AAEA;EACE,wBAAwB;AAC1B;;AAEA,sHAAsH;;AAEtH,sHAAsH;;AAEtH;;EAEE,WAAW;AACb;;AAEA;;EAEE,UAAU;EACV,gCAAgC;EAChC,sCAAsC;EACtC,4BAA4B;EAC5B,gBAAgB;AAClB;;AAEA;EACE,qCAAqC;AACvC;AACA;EACE,qCAAqC;AACvC;;AAEA;;;;EAIE,uBAAuB;AACzB;;AAEA;EACE,aAAa;EACb,eAAe;EACf,WAAW;EACX,8BAA8B;AAChC;;AAEA;EACE,aAAa;EACb,UAAU;EACV,gBAAgB;AAClB;;AAEA;EACE,UAAU;EACV,gBAAgB;AAClB;;AAEA;EACE,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,gBAAgB;EAChB,WAAW;AACb;;AAEA;EACE,iBAAiB;EACjB,mBAAmB;AACrB;AACA,sHAAsH;AACtH,sHAAsH;AACtH;EACE,WAAW;EACX,YAAY;AACd;;AAEA;;;EAGE,aAAa;AACf;;AAEA;EACE,eAAe;EACf,eAAe;AACjB;;AAEA;;;EAGE,SAAS;AACX;;AAEA,sHAAsH;AACtH,sHAAsH;;AAEtH,yBAAyB;AACzB;;EAEE,6BAA6B;AAC/B;AACA,sHAAsH;;AAEtH,sHAAsH;;AAEtH,gCAAgC;AAChC;EACE,kBAAkB;EAClB,WAAW;EACX,oBAAoB;EACpB,sBAAsB;AACxB;;AAEA;EACE,eAAe;AACjB;;AAEA,8BAA8B;AAC9B;EACE,kBAAkB;EAClB,mBAAmB;EACnB,oBAAoB;AACtB;;AAEA,kCAAkC;AAClC;EACE,cAAc;EACd,yBAAyB;EACzB,iBAAiB;EACjB,eAAe;EACf,yBAAyB;EACzB,WAAW;AACb;;AAEA,mDAAmD;AACnD;EACE,2BAA2B;EAC3B,8BAA8B;AAChC;;AAEA;EACE,4BAA4B;EAC5B,+BAA+B;AACjC;;AAEA,mCAAmC;AACnC;EACE,WAAW;EACX,yBAAyB;EACzB,qBAAqB;AACvB;AACA,sHAAsH;AACtH,sHAAsH;AACtH;EACE,YAAY;EACZ,WAAW;EACX,aAAa;EACb,iBAAiB;EACjB,uBAAuB;EACvB,mBAAmB;AACrB;;AAEA;EACE,kBAAkB;EAClB,iBAAiB;EACjB,eAAe;EACf,cAAc;AAChB;;AAEA;EACE,kBAAkB;EAClB,iBAAiB;EACjB,eAAe;EACf,cAAc;AAChB;AACA,sHAAsH;AACtH,sHAAsH;AACtH;EACE,aAAa;EACb,mBAAmB;EACnB,8BAA8B;AAChC;;AAEA;EACE,cAAc;AAChB;;AAEA;EACE,YAAY;EACZ,6BAA6B;AAC/B;;AAEA;EACE,kBAAkB;EAClB,iBAAiB;EACjB,eAAe;EACf,cAAc;EACd,eAAe;AACjB;;AAEA;EACE,cAAc;EACd,0BAA0B;AAC5B;AACA,sHAAsH;AACtH,sHAAsH;AACtH;EACE,eAAe;EACf,SAAS;EACT,OAAO;EACP,WAAW;AACb;;AAEA;EACE,4BAA4B;AAC9B;AACA,sHAAsH;AACtH,mHAAmH;;AAEnH,wEAAwE;AACxE;EACE,mBAAmB;EACnB,gBAAgB;AAClB;;AAEA,kBAAkB;AAClB;EACE,gBAAgB;EAChB,WAAW;EACX;AACF;;AAEA;IACI,kBAAkB;AACtB;;AAEA,sHAAsH;AACtH,kHAAkH;;;AAGlH;EACE,mBAAmB;EACnB,YAAY;AACd","sourcesContent":["/* |----------------------- COMMON STYLE RULES --------------------------------------------------------------------> */\n\n.jp-ReactWidget {\n  color: var(--jp-ui-font-color1);\n  background: var(--jp-layout-color1);\n  align-items: center;\n  padding-top: 20px;\n  padding-bottom: 10px;\n  padding-right: 20px;\n  padding-left: 20px;\n  overflow: auto;\n  min-height: 400px;\n}\n\n.jp-dataviz{\n  margin-top: -8px;\n  min-width: 650px !important;\n}\n\n.marginsNotebook {\n  padding-right: 5px;\n  padding-left: 70px;\n}\n\n/* Any element that fills its parent by width */\n.full-width {\n  width: 100%;\n}\n\n/* Any element that fills its parent by height */\n.full-height-container {\n  height: 100%;\n}\n\n/* Any element that needs margin */\n.margin-right {\n  margin-right: 10px;\n}\n\n/* Any short element */\n.short {\n  height: 26px !important;\n  padding: 0 12px !important;\n}\n\n/* Any centered element */\n.centered {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n}\n\n/* Make element visible and flexible */\n.show_flex {\n  display: flex !important;\n}\n\n/* Add ellipsis */\n.ellipsized {\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  overflow: hidden;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |----------------------- FORMULABAR: GENERAL STYLING -----------------------------------------------------------> */\n\n.formulaFormDivider{\n  border-bottom: 1px solid black;\n  width: 100%;\n  border-color: #B2B2B2;\n  margin-bottom: 10px;\n}\n\n#root__title{\n  border-bottom-width: 0px;\n  margin-bottom: 5px;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |----------------------- FORMULABAR: SIDE-BY-SIDE FIELDS RULES -------------------------------------------------> */\n\n/* Side-by-side container */\n.side-by-side-fields > fieldset {\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: space-between;\n  width: 100%;\n  margin-bottom: 10px;\n  position: relative;\n}\n\n/* Left and right fields of side-by-side container */\n.side-by-side-fields .left-field,\n.side-by-side-fields .right-field {\n  width: 49%;\n}\n\n/* Rewrite left field rules for data-transformation-form */\n.data-transformation-form .left-field {\n  width: 33%;\n}\n\n/* Rewrite right field rules for data-transformation-form */\n.data-transformation-form .right-field {\n  width: 66%;\n}\n\n/* Rules for description inside of side-by-side container */\n.side-by-side-fields .field-description {\n  width: 100%;\n  margin-bottom: 10px;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n\n/* |----------------------- FORMULABAR: REWRITE ITEMS AT ARRAY LEVEL OF TRANSFORMATIONS.JSON ----------------------> */\n\n/* Item container */\n.array-item {\n  display: flex;\n  align-items: center;\n}\n\n/* Item buttons */\n.array-item-toolbox {\n  margin-bottom: 9px;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n\n/* |----------------------- REWRITE QUERY BUILDER STYLE RULES -----------------------------------------------------> */\n\n#query-form .group-or-rule-container {\n  padding-right: 0;\n}\n\n#query-form .query-builder {\n  margin: 0;\n}\n\n#query-form .query-builder-container {\n  padding: 10px 0;\n  margin-bottom: 20px;\n}\n\n.query-builder-container button {\n  color: #fff;\n  background-color: #337ab7;\n  border-color: #337ab7;\n  display: inline-block;\n  cursor: pointer;\n  padding: 2px 9px;\n  font-size: 14px;\n  line-height: 1.42857143;\n  border-radius: 4px;\n}\n\n/* Make action buttons always visible */\n.group--actions.group--actions--tr {\n  opacity: 1 !important;\n}\n\n/* Style for action buttons */\n.group--actions.group--actions--tr > button {\n  margin-right: 5px;\n}\n\n.group--actions.group--actions--tr > button:last-child {\n  margin-right: 0;\n}\n\n.rule--header > button,\n.group--actions.group--actions--tr > button:nth-child(3) {\n  background: #dc2222;\n  border-color: #dc2222;\n}\n\n/* Styles for rule fields */\n.rule--field,\n.rule--value,\n.rule--operator {\n  width: 30%;\n}\n.rule--operator {\n  max-width: 130px;\n}\n\n.rule--body {\n  display: flex;\n}\n\n.rule--value input {\n  height: 100%;\n  padding: 6px 12px;\n  font-size: 14px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  width: 100%;\n}\n\n/* -------------> Rewrite existing rules for widgets */\n.rule--widget--MULTISELECT,\n.rule--widget--MULTISELECT .widget--widget {\n  width: 100%;\n}\n.rule--widget--NUMBER,\n.rule--widget--NUMBER .widget--widget,\n.rule--widget--TEXT,\n.rule--widget--TEXT .widget--widget{\n  height: 100%;\n  width: 100%;\n}\n/* Set specific width for external block */\n.rule--widget--BOOLEAN {\n  max-width: 70%;\n  width: 170px;\n  height: 100%;\n}\n\n/* Make inner block flex to align elements inside of it */\n.rule--widget--BOOLEAN .widget--widget {\n  display: flex;\n  align-items: center;\n  height: 100%;\n}\n\n/* Remove unnecessary margin from radio button */\n.rule--widget--BOOLEAN .widget--widget input[type=\"radio\"] {\n  margin: 0 10px !important;\n  height: 20px;\n  width: 20px;\n}\n/* <------------------------------------------------- */\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n\n/* |----------------------- DATA VISUALIZER RULES -----------------------------------------------------------------> */\n\n/* |----------- Binder button --------------------------------------->*/\n\n.binderButtonSeparator{\n  margin-bottom: 10px;\n}\n\n.binderButton{\n  background-color: #000000;\n  color: #FFFFFF;\n  border-radius: 1rem;\n  border: 0;\n  padding-top: 5px;\n  padding-bottom: 5px;\n  padding-left: 15px;\n  padding-right: 15px;\n  height: 22px;\n}\n\n.binderButton:hover{\n  color: #FFFFFF;\n  background-color: #5249BA !important;\n  text-decoration: none;\n}\n\n/* <--------------------------------------------------------------|*/\n\n/* |----------- Navigation --------------------------------------->*/\n/* Navigation bar */\n.scroll-nav {\n  overflow-x: auto;\n  overflow-y: hidden;\n  white-space: nowrap;\n  position: relative;\n  z-index: 5;\n}\n\n/* Navigation tab (button) */\n.tab-button {\n  min-width: 77px;\n  height: 30px;\n  background: #FFFFFF;\n  border: 1px solid #DDDDDD;\n  border-right: 0;\n  box-sizing: border-box;\n  border-radius: 4px 0 0 0;\n  font-size: 14px;\n  line-height: 21px;\n  display: inline-block;\n  transition: 0.2s ease;\n}\n\n/* Navigation tab (button) style by hover */\n.tab-button:hover,\n.dropdown-button:hover\n{\n  background-color: #EEEEEE;\n}\n\n/* Navigation tab (button) style if active */\n.tab-button_active {\n  background-color: #ffffff;\n  color: #353EFF !important;\n}\n\n/* Navigation tab (button) style if inactive */\n.tab-button_inactive {\n  color: #959494;\n  background-color: #f6f6f6;\n}\n\n/* Containers for dropdown button */\n.dropdown-container {\n  display: flex;\n}\n\n.dropdown {\n  display: flex;\n  min-width: 97px;\n}\n\n/* Dropdown button container */\n.dropdown-button {\n  height: 30px;\n  padding: 2px 4px;\n  margin-right: 3px;\n  border: 1px solid #DDDDDD;\n  border-left: 0;\n  border-radius: 0 4px 0 0;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n/* Rewrite bootstrap's dropdown menu */\n.dropdown-menu {\n  padding: 0 !important;\n  margin: 0 !important;\n  border-top-left-radius: 0 !important;\n  border-top-right-radius: 0 !important;\n}\n\n/* Rewrite bootstrap's dropdown menu item */\n.dropdown-item {\n  display: block;\n  padding: 2px 10px;\n  color: #212529;\n  width: max-content;\n  text-decoration: none;\n}\n\n.dropdown-item:hover {\n  background-color: #f3f3f3;\n  text-decoration: none;\n  color: #212529;\n}\n\n/* CSS arrow for dropdown container */\n.dropdown-arrow {\n  height: 0;\n  width: 0;\n  border-top: .3em solid;\n  border-right: .3em solid transparent;\n  border-bottom: 0;\n  border-left: .3em solid transparent;\n}\n\n/* Rules for variables button */\n.variables-button {\n  margin-right: 4px;\n  border: 1px solid #CDDCA8;\n  border-top-right-radius: 4px;\n  background-color: #f6f6f6;\n  color: #959494;\n}\n\n.variables-button:hover {\n  background-color: #EEEEEE;\n}\n/* <--------------------------------------------------------------|*/\n\n/* Container for table */\n.tab-item {\n  width: fit-content;\n  max-width: 100%;\n  margin-bottom: 15px;\n  overflow: auto;\n  border: 1px solid #ddd;\n  height: 83%;\n}\n\n.disclaimer {\n  font-size: 12px;\n  color: #2d2d2d;\n  padding: 8px;\n  margin: 0\n}\n\n/* ---> Table rules ------------------------------------------- */\n\n/* Table style */\n.div-table {\n  width: 100%;\n  border-collapse: collapse;\n  display: table;\n  border-color: grey;\n  border-spacing: 2px;\n}\n\n/* Dark header style */\n.thead-dark {\n  background-color: #212529;\n  color: #ffffff;\n}\n\n/* Add padding to all .th children*/\n.th > *{\n  padding: .35rem;\n}\n\n.header {\n  position: relative;\n}\n\n.header:hover > .dropdown-header-button {\n  right: 0;\n}\n\n/* Dropdown button for column headers*/\n.dropdown-header-button {\n  border: 1px solid #949494;\n  transition: right 0.3s ease;\n  position: absolute;\n  width: 34px;\n  max-width: 100%;\n  right: -34px;\n  top: 0;\n  height: 90%;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  border-radius: 4px 0 0 4px;\n  background-color: #969696;\n}\n\n.dropdown-header-button:hover {\n  cursor: pointer;\n}\n\n/* Header for dropdown menu */\n.sort-header {\n  color: #888888;\n  padding: 0 0 0 10px;\n  margin: 0;\n}\n\n/* Dropdown menu for column headers */\n.dropdown-header-menu {\n  padding: 10px;\n  border-radius: 5px;\n  position: absolute;\n  left: 0;\n  top: 50%;\n  z-index: 5;\n  background-color: #e3e3e3;\n  display: none;\n}\n\n/* Position of sort arrow */\n.sort-arrow {\n  position: absolute;\n  right: 10%;\n  top: 0;\n  color: white;\n  display: none;\n}\n\n/* Add different style to index column */\n.index-column-header {\n  background-color: #585757;\n}\n\n/* Style for data type info */\n.data-type-info {\n  color: grey;\n  width: 100%;\n  font-size: 11px;\n  z-index: 1;\n  position: relative;\n}\n\n/* Cell's style */\n.td{\n  padding: .75rem;\n  font-size: 12px;\n}\n\n/* Striped table style */\n.div-table-striped .tbody .tr:nth-of-type(odd) {\n  background-color: rgba(0,0,0,.05);\n}\n\n/* Sticky position for header */\n.sticky {\n  position: sticky;\n  top: 0;\n}\n\n.th, .td {\n  cursor: text;\n}\n\n.tr {\n  width: 100% !important;\n  border-top: 1px solid #dee2e6;\n  align-items: center;\n}\n\n.trash-bin-button {\n  border: none;\n  background-color: transparent;\n}\n\n/* White row for data types background */\n.header-white-row {\n  background-color: white;\n  width: 100%;\n  height: 25px;\n  display: flex;\n  position: absolute;\n  bottom: 0;\n  left: 0;\n  align-items: center;\n  z-index: 1;\n  border-bottom: 1px solid grey;\n}\n\n.delimiter-wrapper {\n  background-color: transparent;\n  width: 8px;\n  position: absolute;\n  top: 0;\n  right: -3px;\n  padding: 0;\n  height: 100%;\n  z-index: 5;\n}\n\n.delimiter {\n  width: 1px;\n  height: 100%;\n  background-color: rgba(128, 128, 128, 0.2);\n  position: absolute;\n  right: 20%;\n}\n\n.delimiter:hover {\n  cursor: col-resize;\n}\n\n/* <------------------------- */\n\n/* <----------------------------------------------------------- */\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |---------------------------------------- PAGINATION PANEL -----------------------------------------------------> */\n\n.pagination-panel {\n  display: flex;\n  border-radius: 3px;\n  flex-wrap: wrap;\n  font-size: 12px;\n}\n\n.pagination-segment {\n  padding: 5px 12px;\n  border: 1px solid hsl(0, 0%, 80%);\n  min-width: 50px;\n  border-radius: 0;\n  transition: all 0.3s ease;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.pagination-page-select {\n  width: 160px;\n}\n\n.pagination-size-select {\n  width: 130px;\n}\n\n.pagination-segment:first-child {\n  border-radius: 3px 0 0 3px;\n}\n\n.pagination-segment:last-child {\n  border-radius: 0 3px 3px 0;\n}\n\nbutton.pagination-segment {\n  background-color: white;\n  color: black;\n}\n\nbutton.pagination-segment:disabled {\n  background-color: #dedede;\n  color: #797979;\n}\n\nbutton.pagination-segment:active {\n  background-color: silver;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |-------------------------------- FEEDBACK BUTTONS STYLE RULES -------------------------------------------------> */\n\n.BinaryFeedback__container,\n.BinaryFeedback__actions {\n  width: 100%;\n}\n\n.BinaryFeedback__positive,\n.BinaryFeedback__negative {\n  width: 50%;\n  border-color: #cccccc !important;\n  justify-content: flex-start !important;\n  padding: 2px 10px !important;\n  min-height: 26px;\n}\n\n.BinaryFeedback__positive {\n  border-radius: 5px 0 0 5px !important;\n}\n.BinaryFeedback__negative {\n  border-radius: 0 5px 5px 0 !important;\n}\n\n.BinaryFeedback__negative:hover p,\n.BinaryFeedback__positive:hover p,\n.BinaryFeedback__selected p,\n.BinaryFeedback__disabled p{\n  color: white !important;\n}\n\n#feedback {\n  display: flex;\n  flex-wrap: wrap;\n  width: 100%;\n  justify-content: space-between;\n}\n\n#feedback__negative-description {\n  display: none;\n  width: 66%;\n  min-width: 310px;\n}\n\n#feedback__buttons {\n  width: 33%;\n  min-width: 230px;\n}\n\n.feedback__content {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  overflow: hidden;\n  width: 100%;\n}\n\n.feedback__buttons-text {\n  margin: 0 0 0 5px;\n  white-space: nowrap;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |--------------------------------- STYLES FOR SVG ICONS --------------------------------------------------------> */\n.svg-magnifier {\n  width: 100%;\n  height: 100%;\n}\n\n.svg-magnifier path,\n.svg-magnifier polygon,\n.svg-magnifier rect {\n  fill: #4691f6;\n}\n\n.svg-magnifier circle {\n  stroke: #4691f6;\n  stroke-width: 1;\n}\n\n.svg-bin path,\n.svg-bin polygon,\n.svg-bin rect {\n  fill: red;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- CHAT WIDGET STYLE -------------------------------------------------------------> */\n\n/* Rewrite native style */\n.Papercups-toggleButtonContainer,\n.Papercups-chatWindowContainer {\n  position: absolute !important;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n\n/* |------------------------------- RADIO BUTTON GROUP STYLE ------------------------------------------------------> */\n\n/* Container for radio buttons */\n.radio-button-group {\n  position: relative;\n  width: 100%;\n  display: inline-flex;\n  vertical-align: middle;\n}\n\n.radio-wrapper {\n  min-width: 65px;\n}\n\n/* Hide default radio button */\n.radio-button {\n  position: absolute;\n  clip: rect(0,0,0,0);\n  pointer-events: none;\n}\n\n/* Label is the wrapper of radio */\n.radio-button-label {\n  color: #0d6efd;\n  border: 1px solid #0d6efd;\n  padding: 6px 12px;\n  cursor: pointer;\n  transition: all 0.7s ease;\n  width: 100%;\n}\n\n/* Set special borders for first and last buttons */\n.radio-button-group > div:first-child > .radio-button-label {\n  border-top-left-radius: 5px;\n  border-bottom-left-radius: 5px;\n}\n\n.radio-button-group > div:last-child .radio-button-label {\n  border-top-right-radius: 5px;\n  border-bottom-right-radius: 5px;\n}\n\n/* Change colors radio is checked */\n.radio-button:checked+.radio-button-label {\n  color: #fff;\n  background-color: #0d6efd;\n  border-color: #0d6efd;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- EMPTY STATE COMPONENT STYLE ---------------------------------------------------> */\n.empty-state__container {\n  height: 100%;\n  width: 100%;\n  display: flex;\n  flex-flow: column;\n  justify-content: center;\n  align-items: center;\n}\n\n.empty-state__title {\n  font-style: normal;\n  font-weight: bold;\n  font-size: 34px;\n  color: #858585;\n}\n\n.empty-state__link {\n  font-style: normal;\n  font-weight: bold;\n  font-size: 14px;\n  color: #109CF1;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- RELOAD BUTTON STYLE -----------------------------------------------------------> */\n.reload-button__container {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n}\n\n.reload-button__container:active *{\n  color: #a4d1f8;\n}\n\n.reload-button__container > button {\n  border: none;\n  background-color: transparent;\n}\n\n.reload-button__container > label{\n  font-style: normal;\n  font-weight: bold;\n  font-size: 12px;\n  color: #109CF1;\n  cursor: pointer;\n}\n\n.reload-button__container:hover > * {\n  color: #23527c;\n  text-decoration: underline;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------------- SPINNER STYLE -----------------------------------------------------------> */\n.spinner-wrapper {\n  position: fixed;\n  top: 28px;\n  left: 0;\n  width: 100%;\n}\n\n.spinner-wrapper > * {\n  position: inherit !important;\n}\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- RESTYLING OF APP -----------------------------------------------------------> */\n\n/* Lines on the top of the widget window removed for more stylized look*/\n:not(.jp-NotebookPanel) > .jp-Toolbar {\n  border-bottom: none;\n  box-shadow: none;\n}\n\n/* Top left logo */\n#jp-MainLogo {\n  margin-left: 3px;\n  width: 26px;\n  background-image: url(logo.png)\n}\n\n#jp-MainLogo > svg {\n    visibility: hidden;\n}\n\n/* <---------------------------------------------------------------------------------------------------------------| */\n/* |------------------------------- CELL FORMULABAR -----------------------------------------------------------> */\n\n\n.jp-InputArea-editor{\n  background: #F7F7F7;\n  border: none;\n}\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "./style/logo.png":
/*!************************!*\
  !*** ./style/logo.png ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (__webpack_require__.p + "dce04bf6a9d2668c86c1066a25a36c42.png");

/***/ }),

/***/ "./style/base.css":
/*!************************!*\
  !*** ./style/base.css ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! !../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js */ "./node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js");
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! !!../node_modules/css-loader/dist/cjs.js!./base.css */ "./node_modules/css-loader/dist/cjs.js!./style/base.css");

            

var options = {};

options.insert = "head";
options.singleton = false;

var update = _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__.default, options);



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__.default.locals || {});

/***/ }),

/***/ "./style/index.js":
/*!************************!*\
  !*** ./style/index.js ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _base_css__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base.css */ "./style/base.css");



/***/ })

}]);
//# sourceMappingURL=style_index_js.61fa6e3e9fbc9d988277.js.map